@@ -170,7 +170,7 @@ class SpeechMixEED(nn.Module):
         self.tokenizer = AutoTokenizer.from_pretrained(nlp_model_config)
         # remove last x layer
         self.encoder_model.encoder.layers = self.encoder_model.encoder.layers[
-                                            :len(self.decoder_model.model.encoder.layers)]
+                                            :-len(self.decoder_model.model.encoder.layers)]
         self.enc_to_dec_proj = nn.Linear(self.encoder_model.config.hidden_size,
                                          self.decoder_model.config.hidden_size).to(self.device)
         self.length_adapter = nn.Conv1d(self.encoder_model.config.hidden_size, self.encoder_model.config.hidden_size,
@@ -180,13 +180,16 @@ class SpeechMixEED(nn.Module):
             for xcoder in [self.encoder_model.named_parameters, self.decoder_model.named_parameters]:
                 for name, param in xcoder():
                     if param.requires_grad:
-                        if any([k in name for k in ["layer_norm", "encoder_attn"]]):
+                        if any([k in name for k in
+                                ["layer_norm", "encoder_attn", 'attention', 'enc_to_dec_proj', 'length_adapter',
+                                 'lm_head', 'shared']]) or (
+                                'encoder' in name and 'self_attn' in name):
                             param.requires_grad = True
                         else:
                             param.requires_grad = False
         elif fne:
             for name, param in self.decoder_model.named_parameters():
-                if param.requires_grad:
+                if param.requires_grad and not any([k in name for k in ['lm_head', 'shared']]):
                     param.requires_grad = False
 
     def forward(self, input_values, decoder_input_ids=None, labels=None):
